@@ -1,5 +1,6 @@
 import pkg_resources
-from typing import List, Dict, Tuple, Union
+from typing import List, Dict, Tuple
+
 
 def load_file(filename: str, directory: str) -> List[List[str]]:
     """Loads a data file stored in the Axelrod library's data subdirectory,
@@ -28,6 +29,7 @@ def load_weights(filename: str ="ann_weights.csv", directory: str ="data") -> Di
         d[name] = (num_features, num_hidden, weights)
     return d
 
+
 def load_pso_tables(filename="pso_gambler.csv", directory="data"):
     """Load lookup tables."""
     rows = load_file(filename, directory)
