@@ -1,14 +1,18 @@
-from axelrod.actions import Action, Actions
+from axelrod.action import Action
 from axelrod.player import Player
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Appeaser(Player):
     """A player who tries to guess what the opponent wants.
 
-    Switch the classifier every time the opponent plays 'D'.
-    Start with 'C', switch between 'C' and 'D' when opponent plays 'D'.
+    Switch the classifier every time the opponent plays D.
+    Start with C, switch between C and D when opponent plays D.
+
+    Names:
+
+    - Appeaser: Original Name by Jochen Müller
     """
 
     name = 'Appeaser'
