@@ -1,9 +1,8 @@
-from axelrod.actions import Actions
+from axelrod.action import Action
 from axelrod.player import Player
 from axelrod.random_ import random_choice
-from axelrod.actions import Action
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class BetterAndBetter(Player):
