@@ -1,9 +1,8 @@
-from axelrod.actions import Actions
+from axelrod.action import Action
 from axelrod.player import Player
 from axelrod.strategy_transformers import InitialTransformer
-from axelrod.actions import Action
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 @InitialTransformer((D, D, D, D, D, C, C), name_prefix=None)
