@@ -1,9 +1,9 @@
-from axelrod.actions import Actions, Action
+from axelrod.action import Action
 from axelrod.player import Player
 
 from typing import List
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Handshake(Player):
@@ -12,7 +12,7 @@ class Handshake(Player):
 
     Names:
 
-    - Handshake: [Robson1989]_
+    - Handshake: [Robson1990]_
     """
 
     name = 'Handshake'
