@@ -1,8 +1,8 @@
-from axelrod.actions import Actions, flip_action, Action
+from axelrod.action import Action
 from axelrod.player import Player
 from axelrod.random_ import random_choice
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Negation(Player):
@@ -12,7 +12,7 @@ class Negation(Player):
 
     Names:
 
-    Negation - [http://www.prisoners-dilemma.com/competition.html]
+    - Negation: [PD2017]_
     """
 
     name = "Negation"
@@ -31,4 +31,4 @@ class Negation(Player):
         if not self.history:
             return random_choice()
         # Act opposite of opponent otherwise
-        return flip_action(opponent.history[-1])
+        return opponent.history[-1].flip()
