@@ -51,10 +51,6 @@ class Retaliate(Player):
                 return D
         return C
 
-    def reset(self):
-        super().reset()
-        self.play_counts = defaultdict(int)
-
 
 class Retaliate2(Retaliate):
     """
@@ -109,7 +105,8 @@ class LimitedRetaliate(Player):
         'manipulates_state': False
     }
 
-    def __init__(self, retaliation_threshold: float = 0.1, retaliation_limit: int = 20) -> None:
+    def __init__(self, retaliation_threshold: float = 0.1,
+                 retaliation_limit: int = 20) -> None:
         """
         Parameters
         ----------
@@ -155,12 +152,6 @@ class LimitedRetaliate(Player):
 
         return C
 
-    def reset(self):
-        super().reset()
-        self.play_counts = defaultdict(int)
-        self.retaliating = False
-        self.retaliation_count = 0
-
 
 class LimitedRetaliate2(LimitedRetaliate):
     """
