@@ -39,10 +39,17 @@ class SequencePlayer(Player):
         for s in self.sequence_generator:
             return self.meta_strategy(s)
 
-    def reset(self):
-        # Be sure to reset the sequence generator
-        super().reset()
-        self.sequence_generator = self.generator_function(*self.generator_args)
+    def __getstate__(self):
+        return_dict = self.__dict__.copy()
+        del return_dict['sequence_generator']
+        return return_dict
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        self.__dict__['sequence_generator'] = self.generator_function(
+            *self.generator_args)
+        for turn in self.history:
+            next(self.sequence_generator)
 
 
 class ThueMorse(SequencePlayer):
